@@ -2,7 +2,33 @@
 --
 -- Gitano command processing
 --
--- Copyright 2012 Daniel Silverstone <dsilvers@digital-scurf.org>
+-- Copyright 2012-2017 Daniel Silverstone <dsilvers@digital-scurf.org>
+-- All rights reserved.
+--
+-- Redistribution and use in source and binary forms, with or without
+-- modification, are permitted provided that the following conditions
+-- are met:
+-- 1. Redistributions of source code must retain the above copyright
+--    notice, this list of conditions and the following disclaimer.
+-- 2. Redistributions in binary form must reproduce the above copyright
+--    notice, this list of conditions and the following disclaimer in the
+--    documentation and/or other materials provided with the distribution.
+-- 3. Neither the name of the author nor the names of their contributors
+--    may be used to endorse or promote products derived from this software
+--    without specific prior written permission.
+--
+-- THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+-- ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+-- IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+-- ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+-- FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+-- DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+-- OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+-- HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+-- LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+-- OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+-- SUCH DAMAGE.
+--
 
 local log = require 'gitano.log'
 local util = require 'gitano.util'
@@ -81,6 +107,59 @@ local function get_cmd(cmdname)
    }
 end
 
+local builtin_version_short = "Get the Gitano version"
+local builtin_version_helptext = [[
+usage: version [machine]
+
+Without an argument, display the version and basic copyright information for
+Gitano in a form which a human can parse.
+
+With the 'machine' command, display the Gitano version as a machine-parseable
+list of values instead.
+
+**NOTE**: the format of the machine-parseable output is not guaranteed stable
+at this time.
+]]
+
+local function builtin_version_validate(config, _, cmdline)
+   if #cmdline > 2 then
+      log.error("usage: version [machine]")
+      return false
+   end
+   if #cmdline == 2 and cmdline[2] ~= "machine" then
+      log.error("usage: version [machine]")
+      return false
+   end
+   return true
+end
+
+local function builtin_version_prep(config, _, cmdline, context)
+   return "allow", "Always allowed to ask for the version"
+end
+
+local function builtin_version_run(config, _, cmdline, env)
+   -- We do this lazily because otherwise circular includes get in our way
+   local _gitano = require "gitano"
+   if #cmdline == 1 then
+      log.state(_gitano.VERSION_STRING)
+      log.state(_gitano.COPYRIGHT)
+   else
+      -- Machine-parseable version
+      log.state(("VERSION:%d.%d.%d"):format(
+	    _gitano.VERSION.major,
+	    _gitano.VERSION.minor,
+	    _gitano.VERSION.patch))
+      log.state(("MAJOR:%d"):format(_gitano.VERSION.major))
+      log.state(("MINOR:%d"):format(_gitano.VERSION.minor))
+      log.state(("PATCH:%d"):format(_gitano.VERSION.patch))
+   end
+   return "exit", 0
+end
+
+assert(register_cmd("version", builtin_version_short, builtin_version_helptext,
+                    builtin_version_validate, builtin_version_prep,
+                    builtin_version_run, false, false))
+
 local builtin_help_short = "Ask for help"
 local builtin_help_helptext = [[
 usage: help [admin|command]
