@@ -2,7 +2,33 @@
 --
 -- Create/destroy/blahblah repositories under Gitano management
 --
--- Copyright 2012 Daniel Silverstone <dsilvers@digital-scurf.org>
+-- Copyright 2012-2017 Daniel Silverstone <dsilvers@digital-scurf.org>
+-- All rights reserved.
+--
+-- Redistribution and use in source and binary forms, with or without
+-- modification, are permitted provided that the following conditions
+-- are met:
+-- 1. Redistributions of source code must retain the above copyright
+--    notice, this list of conditions and the following disclaimer.
+-- 2. Redistributions in binary form must reproduce the above copyright
+--    notice, this list of conditions and the following disclaimer in the
+--    documentation and/or other materials provided with the distribution.
+-- 3. Neither the name of the author nor the names of their contributors
+--    may be used to endorse or promote products derived from this software
+--    without specific prior written permission.
+--
+-- THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
+-- ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+-- IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
+-- ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
+-- FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
+-- DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
+-- OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+-- HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
+-- LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+-- OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+-- SUCH DAMAGE.
+--
 --
 
 local gall = require 'gall'
@@ -165,6 +191,31 @@ end
 function repo_method:run_lace(context)
    self:populate_context(context)
    config.populate_context(self.config, context)
+   --[[ Uncomment this to enable variable dumping.
+   local vardump = luxio.getenv("GITANO_DUMP_VARIABLE_FILE")
+   if vardump then
+      local io = require "io"
+      local pretty = require "pl.pretty"
+      local t
+      local fh = io.open(vardump, "r")
+      if not fh then
+         t = {}
+      else
+         t = pretty.read(fh:read("*a"))
+         fh:close()
+      end
+      local op = context.operation
+      for k, _ in pairs(context) do
+         if not t[k] then
+            t[k] = {}
+         end
+         t[k][op] = true
+      end
+      local fh = io.open(vardump, "w+")
+      fh:write(pretty.write(t))
+      fh:close()
+   end
+   --]]
    return lace.run(self.lace, context)
 end
 
